Class: SleepingKingStudios::Docs::Commands::Installation::InstallTemplates
- Inherits:
-
Cuprum::Command
- Object
- Cuprum::Command
- SleepingKingStudios::Docs::Commands::Installation::InstallTemplates
- Defined in:
- lib/sleeping_king_studios/docs/commands/installation/install_templates.rb
Overview
Installs the Liquid template files.
Instance Method Summary collapse
-
#dry_run? ⇒ Boolean
If true, does not apply filesystem changes.
-
#force? ⇒ Boolean
If true, overwrites existing template files.
-
#ignore_existing? ⇒ Boolean
If true, does not attempt to copy over existing files.
-
#initialize(**options) ⇒ InstallTemplates
constructor
A new instance of InstallTemplates.
-
#verbose? ⇒ Boolean
If true, prints updates to STDOUT.
Constructor Details
#initialize(**options) ⇒ InstallTemplates
Returns a new instance of InstallTemplates.
22 23 24 25 26 27 28 |
# File 'lib/sleeping_king_studios/docs/commands/installation/install_templates.rb', line 22 def initialize(error_stream: $stderr, output_stream: $stdout, **) super() @error_stream = error_stream @output_stream = output_stream = end |
Instance Method Details
#dry_run? ⇒ Boolean
Returns if true, does not apply filesystem changes.
31 32 33 |
# File 'lib/sleeping_king_studios/docs/commands/installation/install_templates.rb', line 31 def dry_run? .fetch(:dry_run, false) end |
#force? ⇒ Boolean
Returns if true, overwrites existing template files.
36 37 38 |
# File 'lib/sleeping_king_studios/docs/commands/installation/install_templates.rb', line 36 def force? .fetch(:force, false) end |
#ignore_existing? ⇒ Boolean
Returns if true, does not attempt to copy over existing files.
41 42 43 |
# File 'lib/sleeping_king_studios/docs/commands/installation/install_templates.rb', line 41 def ignore_existing? .fetch(:ignore_existing, false) end |
#verbose? ⇒ Boolean
Returns if true, prints updates to STDOUT.
46 47 48 |
# File 'lib/sleeping_king_studios/docs/commands/installation/install_templates.rb', line 46 def verbose? .fetch(:verbose, true) end |