Class: SleepingKingStudios::Docs::Errors::FileAlreadyExists

Inherits:
FileError
  • Object
show all
Defined in:
lib/sleeping_king_studios/docs/errors/file_already_exists.rb

Overview

Error returned when attempting to create an existing file.

Constant Summary collapse

TYPE =

Short string used to identify the type of error.

'sleeping_king_studios.docs.errors.file_already_exists'

Instance Attribute Summary

Attributes inherited from FileError

#path

Instance Method Summary collapse

Constructor Details

#initialize(path:) ⇒ FileAlreadyExists

Returns a new instance of FileAlreadyExists.

Parameters:

  • path (String)

    the invalid file path.



12
13
14
# File 'lib/sleeping_king_studios/docs/errors/file_already_exists.rb', line 12

def initialize(path:)
  super(message: default_message(path), path:)
end