Class: SleepingKingStudios::Docs::Errors::FileNotFound

Inherits:
FileError
  • Object
show all
Defined in:
lib/sleeping_king_studios/docs/errors/file_not_found.rb

Overview

Error returned when attempting to parse an invalid file or directory.

Constant Summary collapse

TYPE =

Short string used to identify the type of error.

'sleeping_king_studios.docs.errors.file_not_found'

Instance Attribute Summary

Attributes inherited from FileError

#path

Instance Method Summary collapse

Constructor Details

#initialize(path:) ⇒ FileNotFound



12
13
14
# File 'lib/sleeping_king_studios/docs/errors/file_not_found.rb', line 12

def initialize(path:)
  super(message: default_message(path), path:)
end