Class: SleepingKingStudios::Docs::Errors::InvalidFile

Inherits:
FileError
  • Object
show all
Defined in:
lib/sleeping_king_studios/docs/errors/invalid_file.rb

Overview

Error returned when attempting to create an invalid file.

Constant Summary collapse

TYPE =

Short string used to identify the type of error.

'sleeping_king_studios.docs.errors.invalid_file'

Instance Attribute Summary

Attributes inherited from FileError

#path

Instance Method Summary collapse

Constructor Details

#initialize(path:) ⇒ InvalidFile

Returns a new instance of InvalidFile.

Parameters:

  • path (String)

    the invalid file path.



12
13
14
# File 'lib/sleeping_king_studios/docs/errors/invalid_file.rb', line 12

def initialize(path:)
  super(message: default_message(path), path:)
end