Class: SleepingKingStudios::Docs::Errors::FileAlreadyExists
- Inherits:
-
FileError
- Object
- Cuprum::Error
- FileError
- SleepingKingStudios::Docs::Errors::FileAlreadyExists
- Defined in:
- lib/sleeping_king_studios/docs/errors/file_already_exists.rb
Overview
Error returned when attempting to create an existing file.
Constant Summary collapse
- TYPE =
Short string used to identify the type of error.
'sleeping_king_studios.docs.errors.file_already_exists'
Instance Attribute Summary
Attributes inherited from FileError
Instance Method Summary collapse
-
#initialize(path:) ⇒ FileAlreadyExists
constructor
A new instance of FileAlreadyExists.
Constructor Details
#initialize(path:) ⇒ FileAlreadyExists
Returns a new instance of FileAlreadyExists.
12 13 14 |
# File 'lib/sleeping_king_studios/docs/errors/file_already_exists.rb', line 12 def initialize(path:) super(message: (path), path:) end |