Class: SleepingKingStudios::Docs::Errors::FileNotFound
- Inherits:
-
FileError
- Object
- Cuprum::Error
- FileError
- SleepingKingStudios::Docs::Errors::FileNotFound
- Defined in:
- lib/sleeping_king_studios/docs/errors/file_not_found.rb
Overview
Error returned when attempting to parse an invalid file or directory.
Constant Summary collapse
- TYPE =
Short string used to identify the type of error.
'sleeping_king_studios.docs.errors.file_not_found'
Instance Attribute Summary
Attributes inherited from FileError
Instance Method Summary collapse
-
#initialize(path:) ⇒ FileNotFound
constructor
A new instance of FileNotFound.
Constructor Details
#initialize(path:) ⇒ FileNotFound
12 13 14 |
# File 'lib/sleeping_king_studios/docs/errors/file_not_found.rb', line 12 def initialize(path:) super(message: (path), path:) end |